# Security Policy

## Reporting a Vulnerability

To report security issues please send an e-mail to hello@supranational.net. 

For sensitive information or critical issues, please contact the above e-mail address with 'CRITICAL' in the subject line and we will respond with a mechanism to securely communicate.

Please try to provide a clear description of any issue reported, along with how to reproduce the issue if possible.
